
/////////////////////////////////////////////////////////////////////////////
//
// Feather 0.1
//
// Alden Dima
// alden.dima@nist.gov
//
// National Institute of Standards and Technology
// Software Diagnostics and Conformance Testing Division
// Gaithersburg, MD USA
// http://www.itl.nist.gov/div897
//
// Feather is released by the National Institute of Standards and Technology
// (NIST), an agency of the U.S. Department of Commerce, Gaithersburg
// MD 20899, USA.  Feather bears no warranty, either express or implied.
// NIST does not assume legal liability nor responsibility for a User's
// use of Feather or the results of such use.
//
// Please note that within the United States, copyright protection, under
// Section 105 of the United States Code, Title 17, is not available for
// any work of the United States Government and/or for any works created
// by United States Government employees.  User acknowledges that Feather
// contains work which was created by NIST employees and is therefore
// in the public domain and not subject to copyright. The User may use,
// distribute, or incorporate Feather provided the User acknowledges this via
// an explicit acknowledgment of NIST-related contributions to the User's   
// work. User also agrees to acknowledge, via an explicit acknowledgment,
// that any modifications or alterations have been made to Feather before
// redistribution.
//
//////////////////////////////////////////////////////////////////////////////

package nist.feather.test;

import java.io.File;
import nist.feather.*;

/**
 * Implements a simple set of tests for Feather. These test will evolve with time.
 * 
 * @author Alden Dima
 * @version 0.1
 */
public class Main {
    private static final String line = "-----";
    private static final String nl = System.getProperty("line.separator");
    
	public static void main(String[] argv) {
	    TclInterpreter interp = new TclInterpreter();
	    String result = null;

		try {
		    System.err.println(line);
			result = interp.evalFile(new File("test.tcl"));
			System.err.println("Script returned: " + result);			
			result = interp.evalFile(new File("testb.tcl"));
			System.err.println("Script returned: " + result);
			System.err.println(nl + "Successfully evaluated script file.");
		}
		catch (TclEvalException e) {
			System.err.println(e);
			System.err.println();
		}
		finally {
		    System.err.println(line);
		}

		try {
			result = interp.evalFile(new File("missing.tcl"));
			System.err.println("Script returned: " + result);			
		}
		catch (TclEvalException e) {
		    System.err.println(e);
			System.err.println(nl + "Successfully handled missing script file.");
		}
		finally {
		    System.err.println(line);
		}

        try {
			result = interp.evalFile(null);
			System.err.println("Script returned: " + result);			
		}
		catch (TclEvalException  te) {
		    System.err.println(te);
			System.err.println(nl + "Successfully handled missing script file.");
		}
		catch (NullPointerException e) {
		    System.err.println(e);
			System.err.println(nl + "Successfully handled missing script file.");
		}
		finally {
		    System.err.println(line);
		}

		try {
			result = interp.eval("set a 1");
			System.err.println("Script returned: " + result);			
			result = interp.eval("set b 2");
			System.err.println("Script returned: " + result);
			
			try {
                result = interp.eval("puts [expr $a/0]");
			    System.err.println("Script returned: " + result);
			}
    		catch (TclEvalException e) {
	    		System.err.println("Successfully handled error: " + e);
		    }			
			
			result = interp.eval("expr $a + $b");
			System.err.println("Script returned: " + result);		
			System.err.println(nl + "Successfully evaluated script.");
		}
		catch (TclEvalException e) {
			System.err.println(e);
		}			
		finally {
		    System.err.println(line);
		}
	}
}